@@ -15,14 +15,14 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
+from __future__ import annotations
 
 import warnings
-from typing import Any
 
 from azure.mgmt.containerinstance import ContainerInstanceManagementClient
 from azure.mgmt.containerinstance.models import ContainerGroup
 
+from airflow.exceptions import AirflowProviderDeprecationWarning
 from airflow.providers.microsoft.azure.hooks.base_azure import AzureBaseHook
 
 
@@ -40,10 +40,10 @@ class AzureContainerInstanceHook(AzureBaseHook):
         a service principal which will be used to start the container instance.
     """
 
-    conn_name_attr = 'azure_conn_id'
-    default_conn_name = 'azure_default'
-    conn_type = 'azure_container_instance'
-    hook_name = 'Azure Container Instance'
+    conn_name_attr = "azure_conn_id"
+    default_conn_name = "azure_default"
+    conn_type = "azure_container_instance"
+    hook_name = "Azure Container Instance"
 
     def __init__(self, azure_conn_id: str = default_conn_name) -> None:
         super().__init__(sdk_client=ContainerInstanceManagementClient, conn_id=azure_conn_id)
@@ -67,11 +67,10 @@ class AzureContainerInstanceHook(AzureBaseHook):
         :param name: the name of the container group
         :return: A tuple with the state, exitcode, and details.
             If the exitcode is unknown 0 is returned.
-        :rtype: tuple(state,exitcode,details)
         """
         warnings.warn(
             "get_state_exitcode_details() is deprecated. Related method is get_state()",
-            DeprecationWarning,
+            AirflowProviderDeprecationWarning,
             stacklevel=2,
         )
         cg_state = self.get_state(resource_group, name)
@@ -85,23 +84,23 @@ class AzureContainerInstanceHook(AzureBaseHook):
         :param resource_group: the name of the resource group
         :param name: the name of the container group
         :return: A list of the event messages
-        :rtype: list[str]
         """
         warnings.warn(
-            "get_messages() is deprecated. Related method is get_state()", DeprecationWarning, stacklevel=2
+            "get_messages() is deprecated. Related method is get_state()",
+            AirflowProviderDeprecationWarning,
+            stacklevel=2,
         )
         cg_state = self.get_state(resource_group, name)
         instance_view = cg_state.containers[0].instance_view
         return [event.message for event in instance_view.events]
 
-    def get_state(self, resource_group: str, name: str) -> Any:
+    def get_state(self, resource_group: str, name: str) -> ContainerGroup:
         """
         Get the state of a container group
 
         :param resource_group: the name of the resource group
         :param name: the name of the container group
         :return: ContainerGroup
-        :rtype: ~azure.mgmt.containerinstance.models.ContainerGroup
         """
         return self.connection.container_groups.get(resource_group, name, raw=False)
 
@@ -113,7 +112,6 @@ class AzureContainerInstanceHook(AzureBaseHook):
         :param name: the name of the container group
         :param tail: the size of the tail
         :return: A list of log messages
-        :rtype: list[str]
         """
         logs = self.connection.container.list_logs(resource_group, name, name, tail=tail)
         return logs.content.splitlines(True)
