@@ -19,7 +19,7 @@ from __future__ import annotations
 import warnings
 from typing import TYPE_CHECKING, Any, Sequence
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.models import BaseOperator
 from airflow.providers.microsoft.azure.hooks.data_lake import AzureDataLakeHook
 
@@ -56,7 +56,7 @@ class LocalFilesystemToADLSOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = ("local_path", "remote_path")
-    ui_color = '#e4f0e8'
+    ui_color = "#e4f0e8"
 
     def __init__(
         self,
@@ -68,7 +68,7 @@ class LocalFilesystemToADLSOperator(BaseOperator):
         buffersize: int = 4194304,
         blocksize: int = 4194304,
         extra_upload_options: dict[str, Any] | None = None,
-        azure_data_lake_conn_id: str = 'azure_data_lake_default',
+        azure_data_lake_conn_id: str = "azure_data_lake_default",
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -82,12 +82,12 @@ class LocalFilesystemToADLSOperator(BaseOperator):
         self.azure_data_lake_conn_id = azure_data_lake_conn_id
 
     def execute(self, context: Context) -> None:
-        if '**' in self.local_path:
+        if "**" in self.local_path:
             raise AirflowException("Recursive glob patterns using `**` are not supported")
         if not self.extra_upload_options:
             self.extra_upload_options = {}
         hook = AzureDataLakeHook(azure_data_lake_conn_id=self.azure_data_lake_conn_id)
-        self.log.info('Uploading %s to %s', self.local_path, self.remote_path)
+        self.log.info("Uploading %s to %s", self.local_path, self.remote_path)
         return hook.upload_file(
             local_path=self.local_path,
             remote_path=self.remote_path,
@@ -110,7 +110,7 @@ class LocalToAzureDataLakeStorageOperator(LocalFilesystemToADLSOperator):
             """This class is deprecated.
             Please use
             `airflow.providers.microsoft.azure.transfers.local_to_adls.LocalFilesystemToADLSOperator`.""",
-            DeprecationWarning,
+            AirflowProviderDeprecationWarning,
             stacklevel=3,
         )
         super().__init__(*args, **kwargs)
